==> haskell-vault-0.3.1.5-257-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-IMEMFFEePP0AkwAGAJ7sH7
key:                  vault-0.3.1.5-IMEMFFEePP0AkwAGAJ7sH7
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  5612f2f9aba9ff3b1c5ab7cd9679ac47
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-IMEMFFEePP0AkwAGAJ7sH7
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-92QHxum7zjW25fH5Mdbvto
    unordered-containers-0.2.20-L0GY6JfHBKC8QjVdSVYiO8

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.5-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-LD9Z0Bth56RKweBL8MUoee
key:                  vault-0.3.1.5-LD9Z0Bth56RKweBL8MUoee
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  1f8f4774cc019db2a3f264d375a9a1f1
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-LD9Z0Bth56RKweBL8MUoee
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-GlxcJ9XR4pRDbsSt4txSan
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
